
Introduction
============

Starbear allow creating interactive local web applications in Python very easily.

* The entire app is a single async function.
* Call Python functions from JS, call JS functions from Python.
* No subroutes: Starbear automatically creates the endpoints you need.


Install
-------

.. code-block:: bash

    pip install starbear
